from django.templatetags.static import static
from django.utils.html import format_html

from wagtail import hooks


@hooks.register('insert_editor_css')
def editor_css():
    return format_html(
        '<link rel="stylesheet" href="{}">',
        static('wagtail_cblocks/css/editor.css'),
    )
