# Generated by Django 4.1.7 on 2023-03-30 11:38

from django.db import migrations, models
import django.db.models.deletion
import wagtail.blocks
import wagtail.documents.blocks
import wagtail.fields
import wagtail.images.blocks
import wagtail_cblocks.blocks


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ('wagtailcore', '0078_referenceindex'),
    ]

    operations = [
        migrations.CreateModel(
            name='StandardPage',
            fields=[
                (
                    'page_ptr',
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to='wagtailcore.page',
                    ),
                ),
                (
                    'body',
                    wagtail.fields.StreamField(
                        [
                            (
                                'title_block',
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            'text',
                                            wagtail.blocks.CharBlock(
                                                form_classname='title',
                                                label='Title',
                                            ),
                                        ),
                                        (
                                            'level',
                                            wagtail.blocks.ChoiceBlock(
                                                choices=[
                                                    (2, 'Level 2 heading'),
                                                    (3, 'Level 3 heading'),
                                                    (4, 'Level 4 heading'),
                                                    (5, 'Level 5 heading'),
                                                ],
                                                label='Level',
                                            ),
                                        ),
                                    ]
                                ),
                            ),
                            (
                                'paragraph_block',
                                wagtail_cblocks.blocks.ParagraphBlock(),
                            ),
                            (
                                'button_block',
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            'text',
                                            wagtail.blocks.CharBlock(
                                                label='Text'
                                            ),
                                        ),
                                        (
                                            'link',
                                            wagtail.blocks.StructBlock(
                                                [
                                                    (
                                                        'target',
                                                        wagtail.blocks.StreamBlock(
                                                            [
                                                                (
                                                                    'page',
                                                                    wagtail.blocks.PageChooserBlock(
                                                                        icon='doc-empty-inverse',
                                                                        label='Page',
                                                                    ),
                                                                ),
                                                                (
                                                                    'document',
                                                                    wagtail.documents.blocks.DocumentChooserBlock(
                                                                        icon='doc-full',
                                                                        label='Document',
                                                                    ),
                                                                ),
                                                                (
                                                                    'image',
                                                                    wagtail.images.blocks.ImageChooserBlock(
                                                                        label='Image'
                                                                    ),
                                                                ),
                                                                (
                                                                    'url',
                                                                    wagtail.blocks.URLBlock(
                                                                        label='External link'
                                                                    ),
                                                                ),
                                                                (
                                                                    'anchor',
                                                                    wagtail.blocks.CharBlock(
                                                                        help_text='An anchor in the current page, for example: <code>#target-id</code>.',
                                                                        label='Anchor link',
                                                                    ),
                                                                ),
                                                            ],
                                                            required=True,
                                                        ),
                                                    )
                                                ],
                                                required=True,
                                            ),
                                        ),
                                        (
                                            'style',
                                            wagtail.blocks.ChoiceBlock(
                                                choices=[
                                                    ('primary', 'Primary'),
                                                    ('secondary', 'Secondary'),
                                                    (
                                                        'primary-lg',
                                                        'Large primary',
                                                    ),
                                                ]
                                            ),
                                        ),
                                    ],
                                    default_style='primary-lg',
                                ),
                            ),
                            (
                                'image_block',
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            'image',
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label='Image'
                                            ),
                                        ),
                                        (
                                            'caption',
                                            wagtail.blocks.CharBlock(
                                                label='Caption', required=False
                                            ),
                                        ),
                                        (
                                            'link',
                                            wagtail.blocks.StructBlock(
                                                [
                                                    (
                                                        'target',
                                                        wagtail.blocks.StreamBlock(
                                                            [
                                                                (
                                                                    'page',
                                                                    wagtail.blocks.PageChooserBlock(
                                                                        icon='doc-empty-inverse',
                                                                        label='Page',
                                                                    ),
                                                                ),
                                                                (
                                                                    'document',
                                                                    wagtail.documents.blocks.DocumentChooserBlock(
                                                                        icon='doc-full',
                                                                        label='Document',
                                                                    ),
                                                                ),
                                                                (
                                                                    'image',
                                                                    wagtail.images.blocks.ImageChooserBlock(
                                                                        label='Image'
                                                                    ),
                                                                ),
                                                                (
                                                                    'url',
                                                                    wagtail.blocks.URLBlock(
                                                                        label='External link'
                                                                    ),
                                                                ),
                                                                (
                                                                    'anchor',
                                                                    wagtail.blocks.CharBlock(
                                                                        help_text='An anchor in the current page, for example: <code>#target-id</code>.',
                                                                        label='Anchor link',
                                                                    ),
                                                                ),
                                                            ],
                                                            required=False,
                                                        ),
                                                    )
                                                ],
                                                required=False,
                                            ),
                                        ),
                                    ]
                                ),
                            ),
                            (
                                'hero_block',
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            'blocks',
                                            wagtail.blocks.StreamBlock(
                                                [
                                                    (
                                                        'title_block',
                                                        wagtail.blocks.StructBlock(
                                                            [
                                                                (
                                                                    'text',
                                                                    wagtail.blocks.CharBlock(
                                                                        form_classname='title',
                                                                        label='Title',
                                                                    ),
                                                                ),
                                                                (
                                                                    'level',
                                                                    wagtail.blocks.ChoiceBlock(
                                                                        choices=[
                                                                            (
                                                                                2,
                                                                                'Level 2 heading',
                                                                            ),
                                                                            (
                                                                                3,
                                                                                'Level 3 heading',
                                                                            ),
                                                                            (
                                                                                4,
                                                                                'Level 4 heading',
                                                                            ),
                                                                            (
                                                                                5,
                                                                                'Level 5 heading',
                                                                            ),
                                                                        ],
                                                                        label='Level',
                                                                    ),
                                                                ),
                                                            ]
                                                        ),
                                                    ),
                                                    (
                                                        'paragraph_block',
                                                        wagtail_cblocks.blocks.ParagraphBlock(),
                                                    ),
                                                    (
                                                        'button_block',
                                                        wagtail.blocks.StructBlock(
                                                            [
                                                                (
                                                                    'text',
                                                                    wagtail.blocks.CharBlock(
                                                                        label='Text'
                                                                    ),
                                                                ),
                                                                (
                                                                    'link',
                                                                    wagtail.blocks.StructBlock(
                                                                        [
                                                                            (
                                                                                'target',
                                                                                wagtail.blocks.StreamBlock(
                                                                                    [
                                                                                        (
                                                                                            'page',
                                                                                            wagtail.blocks.PageChooserBlock(
                                                                                                icon='doc-empty-inverse',
                                                                                                label='Page',
                                                                                            ),
                                                                                        ),
                                                                                        (
                                                                                            'document',
                                                                                            wagtail.documents.blocks.DocumentChooserBlock(
                                                                                                icon='doc-full',
                                                                                                label='Document',
                                                                                            ),
                                                                                        ),
                                                                                        (
                                                                                            'image',
                                                                                            wagtail.images.blocks.ImageChooserBlock(
                                                                                                label='Image'
                                                                                            ),
                                                                                        ),
                                                                                        (
                                                                                            'url',
                                                                                            wagtail.blocks.URLBlock(
                                                                                                label='External link'
                                                                                            ),
                                                                                        ),
                                                                                        (
                                                                                            'anchor',
                                                                                            wagtail.blocks.CharBlock(
                                                                                                help_text='An anchor in the current page, for example: <code>#target-id</code>.',
                                                                                                label='Anchor link',
                                                                                            ),
                                                                                        ),
                                                                                    ],
                                                                                    required=True,
                                                                                ),
                                                                            )
                                                                        ],
                                                                        required=True,
                                                                    ),
                                                                ),
                                                                (
                                                                    'style',
                                                                    wagtail.blocks.ChoiceBlock(
                                                                        choices=[
                                                                            (
                                                                                'primary',
                                                                                'Primary',
                                                                            ),
                                                                            (
                                                                                'secondary',
                                                                                'Secondary',
                                                                            ),
                                                                            (
                                                                                'primary-lg',
                                                                                'Large primary',
                                                                            ),
                                                                        ]
                                                                    ),
                                                                ),
                                                            ],
                                                            default_style='primary-lg',
                                                        ),
                                                    ),
                                                    (
                                                        'image_block',
                                                        wagtail.blocks.StructBlock(
                                                            [
                                                                (
                                                                    'image',
                                                                    wagtail.images.blocks.ImageChooserBlock(
                                                                        label='Image'
                                                                    ),
                                                                ),
                                                                (
                                                                    'caption',
                                                                    wagtail.blocks.CharBlock(
                                                                        label='Caption',
                                                                        required=False,
                                                                    ),
                                                                ),
                                                                (
                                                                    'link',
                                                                    wagtail.blocks.StructBlock(
                                                                        [
                                                                            (
                                                                                'target',
                                                                                wagtail.blocks.StreamBlock(
                                                                                    [
                                                                                        (
                                                                                            'page',
                                                                                            wagtail.blocks.PageChooserBlock(
                                                                                                icon='doc-empty-inverse',
                                                                                                label='Page',
                                                                                            ),
                                                                                        ),
                                                                                        (
                                                                                            'document',
                                                                                            wagtail.documents.blocks.DocumentChooserBlock(
                                                                                                icon='doc-full',
                                                                                                label='Document',
                                                                                            ),
                                                                                        ),
                                                                                        (
                                                                                            'image',
                                                                                            wagtail.images.blocks.ImageChooserBlock(
                                                                                                label='Image'
                                                                                            ),
                                                                                        ),
                                                                                        (
                                                                                            'url',
                                                                                            wagtail.blocks.URLBlock(
                                                                                                label='External link'
                                                                                            ),
                                                                                        ),
                                                                                        (
                                                                                            'anchor',
                                                                                            wagtail.blocks.CharBlock(
                                                                                                help_text='An anchor in the current page, for example: <code>#target-id</code>.',
                                                                                                label='Anchor link',
                                                                                            ),
                                                                                        ),
                                                                                    ],
                                                                                    required=False,
                                                                                ),
                                                                            )
                                                                        ],
                                                                        required=False,
                                                                    ),
                                                                ),
                                                            ]
                                                        ),
                                                    ),
                                                    (
                                                        'columns_block',
                                                        wagtail.blocks.StructBlock(
                                                            [
                                                                (
                                                                    'columns',
                                                                    wagtail.blocks.ListBlock(
                                                                        wagtail.blocks.StreamBlock(
                                                                            [
                                                                                (
                                                                                    'title_block',
                                                                                    wagtail.blocks.StructBlock(
                                                                                        [
                                                                                            (
                                                                                                'text',
                                                                                                wagtail.blocks.CharBlock(
                                                                                                    form_classname='title',
                                                                                                    label='Title',
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'level',
                                                                                                wagtail.blocks.ChoiceBlock(
                                                                                                    choices=[
                                                                                                        (
                                                                                                            2,
                                                                                                            'Level 2 heading',
                                                                                                        ),
                                                                                                        (
                                                                                                            3,
                                                                                                            'Level 3 heading',
                                                                                                        ),
                                                                                                        (
                                                                                                            4,
                                                                                                            'Level 4 heading',
                                                                                                        ),
                                                                                                        (
                                                                                                            5,
                                                                                                            'Level 5 heading',
                                                                                                        ),
                                                                                                    ],
                                                                                                    label='Level',
                                                                                                ),
                                                                                            ),
                                                                                        ]
                                                                                    ),
                                                                                ),
                                                                                (
                                                                                    'paragraph_block',
                                                                                    wagtail_cblocks.blocks.ParagraphBlock(),
                                                                                ),
                                                                                (
                                                                                    'button_block',
                                                                                    wagtail.blocks.StructBlock(
                                                                                        [
                                                                                            (
                                                                                                'text',
                                                                                                wagtail.blocks.CharBlock(
                                                                                                    label='Text'
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'link',
                                                                                                wagtail.blocks.StructBlock(
                                                                                                    [
                                                                                                        (
                                                                                                            'target',
                                                                                                            wagtail.blocks.StreamBlock(
                                                                                                                [
                                                                                                                    (
                                                                                                                        'page',
                                                                                                                        wagtail.blocks.PageChooserBlock(
                                                                                                                            icon='doc-empty-inverse',
                                                                                                                            label='Page',
                                                                                                                        ),
                                                                                                                    ),
                                                                                                                    (
                                                                                                                        'document',
                                                                                                                        wagtail.documents.blocks.DocumentChooserBlock(
                                                                                                                            icon='doc-full',
                                                                                                                            label='Document',
                                                                                                                        ),
                                                                                                                    ),
                                                                                                                    (
                                                                                                                        'image',
                                                                                                                        wagtail.images.blocks.ImageChooserBlock(
                                                                                                                            label='Image'
                                                                                                                        ),
                                                                                                                    ),
                                                                                                                    (
                                                                                                                        'url',
                                                                                                                        wagtail.blocks.URLBlock(
                                                                                                                            label='External link'
                                                                                                                        ),
                                                                                                                    ),
                                                                                                                    (
                                                                                                                        'anchor',
                                                                                                                        wagtail.blocks.CharBlock(
                                                                                                                            help_text='An anchor in the current page, for example: <code>#target-id</code>.',
                                                                                                                            label='Anchor link',
                                                                                                                        ),
                                                                                                                    ),
                                                                                                                ],
                                                                                                                required=True,
                                                                                                            ),
                                                                                                        )
                                                                                                    ],
                                                                                                    required=True,
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'style',
                                                                                                wagtail.blocks.ChoiceBlock(
                                                                                                    choices=[
                                                                                                        (
                                                                                                            'primary',
                                                                                                            'Primary',
                                                                                                        ),
                                                                                                        (
                                                                                                            'secondary',
                                                                                                            'Secondary',
                                                                                                        ),
                                                                                                        (
                                                                                                            'primary-lg',
                                                                                                            'Large primary',
                                                                                                        ),
                                                                                                    ]
                                                                                                ),
                                                                                            ),
                                                                                        ],
                                                                                        default_style='primary-lg',
                                                                                    ),
                                                                                ),
                                                                                (
                                                                                    'image_block',
                                                                                    wagtail.blocks.StructBlock(
                                                                                        [
                                                                                            (
                                                                                                'image',
                                                                                                wagtail.images.blocks.ImageChooserBlock(
                                                                                                    label='Image'
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'caption',
                                                                                                wagtail.blocks.CharBlock(
                                                                                                    label='Caption',
                                                                                                    required=False,
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'link',
                                                                                                wagtail.blocks.StructBlock(
                                                                                                    [
                                                                                                        (
                                                                                                            'target',
                                                                                                            wagtail.blocks.StreamBlock(
                                                                                                                [
                                                                                                                    (
                                                                                                                        'page',
                                                                                                                        wagtail.blocks.PageChooserBlock(
                                                                                                                            icon='doc-empty-inverse',
                                                                                                                            label='Page',
                                                                                                                        ),
                                                                                                                    ),
                                                                                                                    (
                                                                                                                        'document',
                                                                                                                        wagtail.documents.blocks.DocumentChooserBlock(
                                                                                                                            icon='doc-full',
                                                                                                                            label='Document',
                                                                                                                        ),
                                                                                                                    ),
                                                                                                                    (
                                                                                                                        'image',
                                                                                                                        wagtail.images.blocks.ImageChooserBlock(
                                                                                                                            label='Image'
                                                                                                                        ),
                                                                                                                    ),
                                                                                                                    (
                                                                                                                        'url',
                                                                                                                        wagtail.blocks.URLBlock(
                                                                                                                            label='External link'
                                                                                                                        ),
                                                                                                                    ),
                                                                                                                    (
                                                                                                                        'anchor',
                                                                                                                        wagtail.blocks.CharBlock(
                                                                                                                            help_text='An anchor in the current page, for example: <code>#target-id</code>.',
                                                                                                                            label='Anchor link',
                                                                                                                        ),
                                                                                                                    ),
                                                                                                                ],
                                                                                                                required=False,
                                                                                                            ),
                                                                                                        )
                                                                                                    ],
                                                                                                    required=False,
                                                                                                ),
                                                                                            ),
                                                                                        ]
                                                                                    ),
                                                                                ),
                                                                            ]
                                                                        ),
                                                                        collapsed=True,
                                                                        form_classname='columns-block-list',
                                                                        label='Columns',
                                                                    ),
                                                                ),
                                                                (
                                                                    'horizontal_align',
                                                                    wagtail.blocks.ChoiceBlock(
                                                                        choices=[
                                                                            (
                                                                                'start',
                                                                                'Left',
                                                                            ),
                                                                            (
                                                                                'center',
                                                                                'Center',
                                                                            ),
                                                                            (
                                                                                'end',
                                                                                'Right',
                                                                            ),
                                                                        ],
                                                                        label='Horizontal alignment',
                                                                        required=False,
                                                                    ),
                                                                ),
                                                            ]
                                                        ),
                                                    ),
                                                ],
                                                label='Content',
                                            ),
                                        ),
                                        (
                                            'style',
                                            wagtail.blocks.ChoiceBlock(
                                                choices=[
                                                    ('centered', 'Centered'),
                                                    (
                                                        'responsive',
                                                        'Responsive',
                                                    ),
                                                    ('dark', 'Dark'),
                                                ]
                                            ),
                                        ),
                                    ]
                                ),
                            ),
                            (
                                'columns_block',
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            'columns',
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StreamBlock(
                                                    [
                                                        (
                                                            'title_block',
                                                            wagtail.blocks.StructBlock(
                                                                [
                                                                    (
                                                                        'text',
                                                                        wagtail.blocks.CharBlock(
                                                                            form_classname='title',
                                                                            label='Title',
                                                                        ),
                                                                    ),
                                                                    (
                                                                        'level',
                                                                        wagtail.blocks.ChoiceBlock(
                                                                            choices=[
                                                                                (
                                                                                    2,
                                                                                    'Level 2 heading',
                                                                                ),
                                                                                (
                                                                                    3,
                                                                                    'Level 3 heading',
                                                                                ),
                                                                                (
                                                                                    4,
                                                                                    'Level 4 heading',
                                                                                ),
                                                                                (
                                                                                    5,
                                                                                    'Level 5 heading',
                                                                                ),
                                                                            ],
                                                                            label='Level',
                                                                        ),
                                                                    ),
                                                                ]
                                                            ),
                                                        ),
                                                        (
                                                            'paragraph_block',
                                                            wagtail_cblocks.blocks.ParagraphBlock(),
                                                        ),
                                                        (
                                                            'button_block',
                                                            wagtail.blocks.StructBlock(
                                                                [
                                                                    (
                                                                        'text',
                                                                        wagtail.blocks.CharBlock(
                                                                            label='Text'
                                                                        ),
                                                                    ),
                                                                    (
                                                                        'link',
                                                                        wagtail.blocks.StructBlock(
                                                                            [
                                                                                (
                                                                                    'target',
                                                                                    wagtail.blocks.StreamBlock(
                                                                                        [
                                                                                            (
                                                                                                'page',
                                                                                                wagtail.blocks.PageChooserBlock(
                                                                                                    icon='doc-empty-inverse',
                                                                                                    label='Page',
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'document',
                                                                                                wagtail.documents.blocks.DocumentChooserBlock(
                                                                                                    icon='doc-full',
                                                                                                    label='Document',
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'image',
                                                                                                wagtail.images.blocks.ImageChooserBlock(
                                                                                                    label='Image'
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'url',
                                                                                                wagtail.blocks.URLBlock(
                                                                                                    label='External link'
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'anchor',
                                                                                                wagtail.blocks.CharBlock(
                                                                                                    help_text='An anchor in the current page, for example: <code>#target-id</code>.',
                                                                                                    label='Anchor link',
                                                                                                ),
                                                                                            ),
                                                                                        ],
                                                                                        required=True,
                                                                                    ),
                                                                                )
                                                                            ],
                                                                            required=True,
                                                                        ),
                                                                    ),
                                                                    (
                                                                        'style',
                                                                        wagtail.blocks.ChoiceBlock(
                                                                            choices=[
                                                                                (
                                                                                    'primary',
                                                                                    'Primary',
                                                                                ),
                                                                                (
                                                                                    'secondary',
                                                                                    'Secondary',
                                                                                ),
                                                                                (
                                                                                    'primary-lg',
                                                                                    'Large primary',
                                                                                ),
                                                                            ]
                                                                        ),
                                                                    ),
                                                                ],
                                                                default_style='primary-lg',
                                                            ),
                                                        ),
                                                        (
                                                            'image_block',
                                                            wagtail.blocks.StructBlock(
                                                                [
                                                                    (
                                                                        'image',
                                                                        wagtail.images.blocks.ImageChooserBlock(
                                                                            label='Image'
                                                                        ),
                                                                    ),
                                                                    (
                                                                        'caption',
                                                                        wagtail.blocks.CharBlock(
                                                                            label='Caption',
                                                                            required=False,
                                                                        ),
                                                                    ),
                                                                    (
                                                                        'link',
                                                                        wagtail.blocks.StructBlock(
                                                                            [
                                                                                (
                                                                                    'target',
                                                                                    wagtail.blocks.StreamBlock(
                                                                                        [
                                                                                            (
                                                                                                'page',
                                                                                                wagtail.blocks.PageChooserBlock(
                                                                                                    icon='doc-empty-inverse',
                                                                                                    label='Page',
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'document',
                                                                                                wagtail.documents.blocks.DocumentChooserBlock(
                                                                                                    icon='doc-full',
                                                                                                    label='Document',
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'image',
                                                                                                wagtail.images.blocks.ImageChooserBlock(
                                                                                                    label='Image'
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'url',
                                                                                                wagtail.blocks.URLBlock(
                                                                                                    label='External link'
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'anchor',
                                                                                                wagtail.blocks.CharBlock(
                                                                                                    help_text='An anchor in the current page, for example: <code>#target-id</code>.',
                                                                                                    label='Anchor link',
                                                                                                ),
                                                                                            ),
                                                                                        ],
                                                                                        required=False,
                                                                                    ),
                                                                                )
                                                                            ],
                                                                            required=False,
                                                                        ),
                                                                    ),
                                                                ]
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                collapsed=True,
                                                form_classname='columns-block-list',
                                                label='Columns',
                                            ),
                                        ),
                                        (
                                            'horizontal_align',
                                            wagtail.blocks.ChoiceBlock(
                                                choices=[
                                                    ('start', 'Left'),
                                                    ('center', 'Center'),
                                                    ('end', 'Right'),
                                                ],
                                                label='Horizontal alignment',
                                                required=False,
                                            ),
                                        ),
                                    ]
                                ),
                            ),
                            (
                                'row_columns_block',
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            'columns',
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StreamBlock(
                                                    [
                                                        (
                                                            'title_block',
                                                            wagtail.blocks.StructBlock(
                                                                [
                                                                    (
                                                                        'text',
                                                                        wagtail.blocks.CharBlock(
                                                                            form_classname='title',
                                                                            label='Title',
                                                                        ),
                                                                    ),
                                                                    (
                                                                        'level',
                                                                        wagtail.blocks.ChoiceBlock(
                                                                            choices=[
                                                                                (
                                                                                    2,
                                                                                    'Level 2 heading',
                                                                                ),
                                                                                (
                                                                                    3,
                                                                                    'Level 3 heading',
                                                                                ),
                                                                                (
                                                                                    4,
                                                                                    'Level 4 heading',
                                                                                ),
                                                                                (
                                                                                    5,
                                                                                    'Level 5 heading',
                                                                                ),
                                                                            ],
                                                                            label='Level',
                                                                        ),
                                                                    ),
                                                                ]
                                                            ),
                                                        ),
                                                        (
                                                            'paragraph_block',
                                                            wagtail_cblocks.blocks.ParagraphBlock(),
                                                        ),
                                                        (
                                                            'button_block',
                                                            wagtail.blocks.StructBlock(
                                                                [
                                                                    (
                                                                        'text',
                                                                        wagtail.blocks.CharBlock(
                                                                            label='Text'
                                                                        ),
                                                                    ),
                                                                    (
                                                                        'link',
                                                                        wagtail.blocks.StructBlock(
                                                                            [
                                                                                (
                                                                                    'target',
                                                                                    wagtail.blocks.StreamBlock(
                                                                                        [
                                                                                            (
                                                                                                'page',
                                                                                                wagtail.blocks.PageChooserBlock(
                                                                                                    icon='doc-empty-inverse',
                                                                                                    label='Page',
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'document',
                                                                                                wagtail.documents.blocks.DocumentChooserBlock(
                                                                                                    icon='doc-full',
                                                                                                    label='Document',
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'image',
                                                                                                wagtail.images.blocks.ImageChooserBlock(
                                                                                                    label='Image'
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'url',
                                                                                                wagtail.blocks.URLBlock(
                                                                                                    label='External link'
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'anchor',
                                                                                                wagtail.blocks.CharBlock(
                                                                                                    help_text='An anchor in the current page, for example: <code>#target-id</code>.',
                                                                                                    label='Anchor link',
                                                                                                ),
                                                                                            ),
                                                                                        ],
                                                                                        required=True,
                                                                                    ),
                                                                                )
                                                                            ],
                                                                            required=True,
                                                                        ),
                                                                    ),
                                                                    (
                                                                        'style',
                                                                        wagtail.blocks.ChoiceBlock(
                                                                            choices=[
                                                                                (
                                                                                    'primary',
                                                                                    'Primary',
                                                                                ),
                                                                                (
                                                                                    'secondary',
                                                                                    'Secondary',
                                                                                ),
                                                                                (
                                                                                    'primary-lg',
                                                                                    'Large primary',
                                                                                ),
                                                                            ]
                                                                        ),
                                                                    ),
                                                                ],
                                                                default_style='primary-lg',
                                                            ),
                                                        ),
                                                        (
                                                            'image_block',
                                                            wagtail.blocks.StructBlock(
                                                                [
                                                                    (
                                                                        'image',
                                                                        wagtail.images.blocks.ImageChooserBlock(
                                                                            label='Image'
                                                                        ),
                                                                    ),
                                                                    (
                                                                        'caption',
                                                                        wagtail.blocks.CharBlock(
                                                                            label='Caption',
                                                                            required=False,
                                                                        ),
                                                                    ),
                                                                    (
                                                                        'link',
                                                                        wagtail.blocks.StructBlock(
                                                                            [
                                                                                (
                                                                                    'target',
                                                                                    wagtail.blocks.StreamBlock(
                                                                                        [
                                                                                            (
                                                                                                'page',
                                                                                                wagtail.blocks.PageChooserBlock(
                                                                                                    icon='doc-empty-inverse',
                                                                                                    label='Page',
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'document',
                                                                                                wagtail.documents.blocks.DocumentChooserBlock(
                                                                                                    icon='doc-full',
                                                                                                    label='Document',
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'image',
                                                                                                wagtail.images.blocks.ImageChooserBlock(
                                                                                                    label='Image'
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'url',
                                                                                                wagtail.blocks.URLBlock(
                                                                                                    label='External link'
                                                                                                ),
                                                                                            ),
                                                                                            (
                                                                                                'anchor',
                                                                                                wagtail.blocks.CharBlock(
                                                                                                    help_text='An anchor in the current page, for example: <code>#target-id</code>.',
                                                                                                    label='Anchor link',
                                                                                                ),
                                                                                            ),
                                                                                        ],
                                                                                        required=False,
                                                                                    ),
                                                                                )
                                                                            ],
                                                                            required=False,
                                                                        ),
                                                                    ),
                                                                ]
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                collapsed=True,
                                                form_classname='columns-block-list',
                                                label='Columns',
                                            ),
                                        ),
                                        (
                                            'horizontal_align',
                                            wagtail.blocks.ChoiceBlock(
                                                choices=[
                                                    ('start', 'Left'),
                                                    ('center', 'Center'),
                                                    ('end', 'Right'),
                                                ],
                                                label='Horizontal alignment',
                                                required=False,
                                            ),
                                        ),
                                        (
                                            'layout',
                                            wagtail.blocks.ChoiceBlock(
                                                choices=[
                                                    ('2', '2-columns'),
                                                    ('3', '3-columns'),
                                                    ('4', '4-columns'),
                                                    ('auto', 'natural width'),
                                                ]
                                            ),
                                        ),
                                    ]
                                ),
                            ),
                        ],
                        use_json_field=True,
                    ),
                ),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
    ]
